[Xenial SRU][PATCH] UBUNTU: SAUCE: (no-up): ASoC: Intel: bytcr-rt5660: Fix noise in line-out

Shrirang Bagul shrirang.bagul at canonical.com
Thu Mar 23 09:42:18 UTC 2017


BugLink: http://bugs.launchpad.net/bugs/1675327

Replace bitclock by mclk as PLL source to fix noise in audio output from
line-out jack.

Signed-off-by: Shrirang Bagul <shrirang.bagul at canonical.com>
---
 sound/soc/intel/boards/bytcr_rt5660.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/sound/soc/intel/boards/bytcr_rt5660.c b/sound/soc/intel/boards/bytcr_rt5660.c
index b51706a..096e76f 100644
--- a/sound/soc/intel/boards/bytcr_rt5660.c
+++ b/sound/soc/intel/boards/bytcr_rt5660.c
@@ -85,10 +85,10 @@ static int byt_rt5660_aif1_hw_params(struct snd_pcm_substream *substream,
 		return ret;
 	}
 
 	/* use bitclock as PLL input */
 	/* 2x15 bit slots on SSP2 */
-	ret = snd_soc_dai_set_pll(codec_dai, 0, RT5660_PLL1_S_BCLK,
-				params_rate(params) * 50,
+	ret = snd_soc_dai_set_pll(codec_dai, 0, RT5660_PLL1_S_MCLK,
+				19200000,
 				params_rate(params) * 512);
 
 	if (ret < 0) {
@@ -85,10 +85,10 @@ static int byt_rt5660_aif1_hw_params(struct snd_pcm_substream *substream,
 	}
 
-	/* use bitclock as PLL input */
+	/* use mclk as PLL input */
 	/* 2x15 bit slots on SSP2 */
-- 
2.9.3





More information about the kernel-team mailing list